Forecaster

Struct Forecaster 

pub struct Forecaster<M>
where M: Fit,
{ /* private fields */ }
A high-level API to fit and predict time series forecasting models.

The Forecaster type allows you to combine a model with a set of transformations and fit it to a time series, then use the fitted model to make predictions. The predictions are back-transformed using the inverse of the transformations applied to the input data.

Implementations

Source

impl<M> Forecaster<M>
where M: Fit, <M as Fit>::Fitted: Predict,

pub fn new(model: M) -> Forecaster<M>

Create a new Forecaster with the given model.

pub fn with_transformers( self, transformers: Vec<Box<dyn Transformer>>, ) -> Forecaster<M>

Set the transformations to be applied to the input data.

pub fn fit<D>(&mut self, y: D) -> Result<(), Error>
where D: Data + Clone,

Fit the model to the given time series.

pub fn predict( &self, horizon: usize, level: impl Into<Option<f64>>, ) -> Result<Forecast, Error>

Predict the next horizon values, optionally including prediction intervals at the given level.

pub fn predict_in_sample( &self, level: impl Into<Option<f64>>, ) -> Result<Forecast, Error>

Produce in-sample forecasts, optionally including prediction intervals at the given level.