MADDetector

Struct MADDetector 

pub struct MADDetector { /* private fields */ }
A detector using the Median Absolute Deviation (MAD) to detect outliers.

Implementations

Source

impl MADDetector

pub fn with_threshold(threshold: f64) -> MADDetector

Create a new MAD detector with the given threshold.

pub fn with_sensitivity(sensitivity: f64) -> Result<MADDetector, Error>

Create a new MAD detector with the given sensitivity.

At detection-time, a sensible value for threshold will be calculated using the scale of the data and the sensitivity value.

pub fn set_threshold(&mut self, threshold: f64)

Set threshold for the MAD detector.

Example
use augurs::outlier::MADDetector;

let mut detector = MADDetector::with_threshold(1.0);
detector.set_threshold(3.0);
pub fn set_sensitivity(&mut self, sensitivity: f64) -> Result<(), Error>

Set sensitivity for the MAD detector.

Example
use augurs::outlier::MADDetector;

let mut detector = MADDetector::with_sensitivity(0.5).expect("sensitivity is between 0.0 and 1.0");
detector.set_sensitivity(0.1).expect("sensitivity is between 0.0 and 1.0");
pub fn set_medians(&mut self, medians: Medians)

Set the precalculated medians.

The medians can be calculated using MADDetector::calculate_double_medians.

pub fn calculate_double_medians( data: &[&[f64]], ) -> Result<Medians, PreprocessingError>

Calculate the medians of the unprocessed data.

This can be used to precalculate the medians of a larger set of data, for example.

Errors

Returns an error if the data is empty, contains only NaNs, or if the lower or upper median is 0.0.