pub struct Forecaster<M>where
M: Fit,{ /* private fields */ }Expand description
A high-level API to fit and predict time series forecasting models.
The Forecaster type allows you to combine a model with a set of
transformations and fit it to a time series, then use the fitted model to
make predictions. The predictions are back-transformed using the inverse of
the transformations applied to the input data.
Implementations
Sourceimpl<M> Forecaster<M>
impl<M> Forecaster<M>
Sourcepub fn new(model: M) -> Forecaster<M>
pub fn new(model: M) -> Forecaster<M>
Create a new Forecaster with the given model.
Sourcepub fn with_transformers(
self,
transformers: Vec<Box<dyn Transformer>>,
) -> Forecaster<M>
pub fn with_transformers( self, transformers: Vec<Box<dyn Transformer>>, ) -> Forecaster<M>
Set the transformations to be applied to the input data.